Python Color Math2 Module (colormath2)
======================================

A maintained fork of the unmaintained `python-colormath`_


.. start-badges

|actions|

.. |actions| image:: https://github.com/bkmgit/python-colormath2/workflows/Continuous%20Integration/badge.svg
    :target: https://github.com/bkmgit/python-colormath2/actions
    :alt: Master Build Status

.. end-badges

This module implements a large number of different color operations such as
color space conversions, Delta E, and density to spectral.

Requirements
------------

* numpy
* NetworkX 2.0+
* Python 3.8+

Installation
------------

The easiest way to install colormath2 is via pip::

    $ pip install colormath2

The development dependencies are installed as follows:

    $ pip install 'colormath2[development]'

Documentation
-------------

For documentation, see the project webpage at:

    http://python-colormath.readthedocs.org/

There are also a lot of useful examples under the examples directory within
this directory.

Support
-------

Head over to https://github.com/bkmgit/python-colormath2
and submit an issue if you have any problems or questions.

Legal Mumbo Jumbo
-----------------

Copyright (C) 2008-2023 `Gregory Taylor`_

Copyright (c) 2024 Benson Muite

This software is licensed under the BSD-3-Clause License.

.. _Gregory Taylor: http://gc-taylor.com
.. _python-colormath: https://github.com/gtaylor/python-colormath
